/**
 * FreeRDP: A Remote Desktop Protocol Implementation
 * Version includes
 *
 * Copyright 2013 Thincast Technologies GmbH
 * Copyright 2013 Bernhard Miklautz <bernhard.miklautz@thincast.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef FREERDP_VERSION_H
#define FREERDP_VERSION_H

#define FREERDP_VERSION_MAJOR 3
#define FREERDP_VERSION_MINOR 27
#define FREERDP_VERSION_REVISION 1
#define FREERDP_VERSION_SUFFIX ""
#define FREERDP_API_VERSION "3"
#define FREERDP_VERSION "3.27.1"
#define FREERDP_VERSION_FULL "3.27.1"
#define FREERDP_GIT_REVISION "6099a8d646"
#define FREERDP_USER_AGENT "FreeRDP/3.27.1"
#define FREERDP_VENDOR "FreeRDP"
#define FREERDP_PRODUCT "FreeRDP"

#endif /* FREERDP_VERSION_H */
